<?php

namespace Superrobota\Softskill\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Softskill\Models\Softskill;

class SoftskillPolicy
{

    /**
     * Determine if the given user can view the softskill.
     *
     * @param UserPolicy $user
     * @param Softskill $softskill
     *
     * @return bool
     */
    public function view(UserPolicy $user, Softskill $softskill)
    {
        if ($user->canDo('softskill.softskill.view') && $user->isAdmin()) {
            return true;
        }

        return $softskill->user_id == user_id() && $softskill->user_type == user_type();
    }

    /**
     * Determine if the given user can create a softskill.
     *
     * @param UserPolicy $user
     * @param Softskill $softskill
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('softskill.softskill.create');
    }

    /**
     * Determine if the given user can update the given softskill.
     *
     * @param UserPolicy $user
     * @param Softskill $softskill
     *
     * @return bool
     */
    public function update(UserPolicy $user, Softskill $softskill)
    {
        if ($user->canDo('softskill.softskill.edit') && $user->isAdmin()) {
            return true;
        }

        return $softskill->user_id == user_id() && $softskill->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given softskill.
     *
     * @param UserPolicy $user
     * @param Softskill $softskill
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Softskill $softskill)
    {
        return $softskill->user_id == user_id() && $softskill->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given softskill.
     *
     * @param UserPolicy $user
     * @param Softskill $softskill
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Softskill $softskill)
    {
        if ($user->canDo('softskill.softskill.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given softskill.
     *
     * @param UserPolicy $user
     * @param Softskill $softskill
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Softskill $softskill)
    {
        if ($user->canDo('softskill.softskill.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
